summaryrefslogtreecommitdiff
path: root/vite.config.ts
diff options
context:
space:
mode:
Diffstat (limited to 'vite.config.ts')
-rw-r--r--vite.config.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/vite.config.ts b/vite.config.ts
index 5e62e9a..69d80d1 100644
--- a/vite.config.ts
+++ b/vite.config.ts
@@ -6,9 +6,9 @@ export default defineConfig({
plugins: [react()],
server: {
proxy: {
// Proxy /api requests to the backend server (running on port 3001 by default)
'/api': {
- target: 'http://localhost:3001', // Default backend port, adjust if needed
+ target: 'http://localhost:3000', // Adjust to match backend PORT from .env
changeOrigin: true, // Recommended for virtual hosted sites
secure: false, // Don't verify SSL certs if backend uses self-signed cert in dev
},
@@ -6,9 +6,9 @@ export default defineConfig({
server: {
proxy: {
- // Proxy /api requests to the backend server (running on port 3001 by default)
+ // Proxy /api requests to the backend server (running on port 3000 now)
'/api': {